Plot3D - Some WebGL programming

# WebGL based demo of plot3d from ImageD11

Drop your g-vectors here
Scale Factor:
Pointsize:

Click and drag to rotate. Zoom with mouse wheel or sliders below

Things to fix. Linux fails drag and drop - add in file upload selector. Android fails mouse move, add in touchmove http://developer.sonymobile.com/2011/11/29/xperia-phones-first-to-support-webgl/ Android fails sliders, find hack at http://touchpunch.furf.com/ Clean and comment the entire code. etc.